```{toctree}
---
maxdepth: 2
hidden: true
---
getting-started
toml
readfish.console
guppy-params
FAQ
post-analysis
developers-guide
readfish
changelog
```

# Welcome to the readfish documentation!

```{include} ../README.md
:start-after: <!-- begin-short -->
:end-before: <!-- end-short -->
```

TOML File
---------
For information on the readfish TOML files see {doc}`toml`

```{include} ../README.md
:start-after: <!-- begin-epilog -->
:end-before: <!-- end-epilog -->
```
